@@ -168,7 +168,7 @@ const Application = new Lang.Class({
         aboutDialog.program_name = _("Sound Recorder");
         aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2013' + String.fromCharCode(0x2013) + 'Meg Ford';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
-        aboutDialog.logo_icon_name = 'gnome-sound-recorder';
+        aboutDialog.logo_icon_name = 'org.gnome.SoundRecorder';
         aboutDialog.version = pkg.version;
         aboutDialog.website = 'https://wiki.gnome.org/Apps/SoundRecorder';
         aboutDialog.wrap_license = true;
